@@ -13,11 +13,11 @@ pub struct StorageMeta {
 
 impl StorageMeta {
     pub fn decode(v: &[u8]) -> io::Result<Self> {
-        bson::from_slice(v).map_err(io::Error::other)
+        bson::deserialize_from_slice(v).map_err(io::Error::other)
     }
 
     pub fn encode_to_vec(&self) -> io::Result<Vec<u8>> {
-        bson::to_vec(self).map_err(io::Error::other)
+        bson::serialize_to_vec(self).map_err(io::Error::other)
     }
 }
 
@@ -29,11 +29,11 @@ pub struct IpAddrMapping {
 
 impl IpAddrMapping {
     pub fn decode(v: &[u8]) -> io::Result<Self> {
-        bson::from_slice(v).map_err(io::Error::other)
+        bson::deserialize_from_slice(v).map_err(io::Error::other)
     }
 
     pub fn encode_to_vec(&self) -> io::Result<Vec<u8>> {
-        bson::to_vec(self).map_err(io::Error::other)
+        bson::serialize_to_vec(self).map_err(io::Error::other)
     }
 }
 
@@ -46,10 +46,10 @@ pub struct DomainNameMapping {
 
 impl DomainNameMapping {
     pub fn decode(v: &[u8]) -> io::Result<Self> {
-        bson::from_slice(v).map_err(io::Error::other)
+        bson::deserialize_from_slice(v).map_err(io::Error::other)
     }
 
     pub fn encode_to_vec(&self) -> io::Result<Vec<u8>> {
-        bson::to_vec(self).map_err(io::Error::other)
+        bson::serialize_to_vec(self).map_err(io::Error::other)
     }
 }
