@@ -37,7 +37,7 @@ impl FakeDnsTcpServer {
         context: Arc<ServiceContext>,
         client_config: &ServerAddr,
         manager: Arc<FakeDnsManager>,
-    ) -> io::Result<FakeDnsTcpServer> {
+    ) -> io::Result<Self> {
         let listener = match *client_config {
             ServerAddr::SocketAddr(ref saddr) => {
                 ShadowTcpListener::bind_with_opts(saddr, context.accept_opts()).await?
@@ -50,7 +50,7 @@ impl FakeDnsTcpServer {
             }
         };
 
-        Ok(FakeDnsTcpServer {
+        Ok(Self {
             context,
             listener,
             manager,
@@ -79,7 +79,7 @@ impl FakeDnsTcpServer {
             let context = self.context.clone();
             let manager = self.manager.clone();
             tokio::spawn(async move {
-                if let Err(err) = FakeDnsTcpServer::handle_client(context, peer_addr, stream, manager).await {
+                if let Err(err) = Self::handle_client(context, peer_addr, stream, manager).await {
                     error!(
                         "failed to handle Fake DNS tcp client, peer: {}, err: {}",
                         peer_addr, err
