@@ -1,11 +1,6 @@
 //! Shadowsocks Local Server
 
-use std::{
-    io::{self, ErrorKind},
-    net::SocketAddr,
-    sync::Arc,
-    time::Duration,
-};
+use std::{io, net::SocketAddr, sync::Arc, time::Duration};
 
 use futures::future;
 use log::trace;
@@ -94,7 +89,7 @@ pub struct Server {
 
 impl Server {
     /// Create a shadowsocks local server
-    pub async fn new(config: Config) -> io::Result<Server> {
+    pub async fn new(config: Config) -> io::Result<Self> {
         assert!(config.config_type == ConfigType::Local && !config.local.is_empty());
 
         trace!("{:?}", config);
@@ -223,7 +218,7 @@ impl Server {
             balancer_builder.build().await?
         };
 
-        let mut local_server = Server {
+        let mut local_server = Self {
             balancer: balancer.clone(),
             socks_servers: Vec::new(),
             #[cfg(feature = "local-tunnel")]
@@ -278,7 +273,7 @@ impl Server {
                 ProtocolType::Socks => {
                     let client_addr = match local_config.addr {
                         Some(a) => a,
-                        None => return Err(io::Error::new(ErrorKind::Other, "socks requires local address")),
+                        None => return Err(io::Error::other("socks requires local address")),
                     };
 
                     let mut server_builder = SocksBuilder::with_context(context.clone(), client_addr, balancer);
@@ -314,7 +309,7 @@ impl Server {
                 ProtocolType::Tunnel => {
                     let client_addr = match local_config.addr {
                         Some(a) => a,
-                        None => return Err(io::Error::new(ErrorKind::Other, "tunnel requires local address")),
+                        None => return Err(io::Error::other("tunnel requires local address")),
                     };
 
                     let forward_addr = local_config.forward_addr.expect("tunnel requires forward address");
@@ -349,7 +344,7 @@ impl Server {
                 ProtocolType::Http => {
                     let client_addr = match local_config.addr {
                         Some(a) => a,
-                        None => return Err(io::Error::new(ErrorKind::Other, "http requires local address")),
+                        None => return Err(io::Error::other("http requires local address")),
                     };
 
                     #[allow(unused_mut)]
@@ -367,7 +362,7 @@ impl Server {
                 ProtocolType::Redir => {
                     let client_addr = match local_config.addr {
                         Some(a) => a,
-                        None => return Err(io::Error::new(ErrorKind::Other, "redir requires local address")),
+                        None => return Err(io::Error::other("redir requires local address")),
                     };
 
                     let mut server_builder = RedirBuilder::with_context(context.clone(), client_addr, balancer);
@@ -391,7 +386,7 @@ impl Server {
                 ProtocolType::Dns => {
                     let client_addr = match local_config.addr {
                         Some(a) => a,
-                        None => return Err(io::Error::new(ErrorKind::Other, "dns requires local address")),
+                        None => return Err(io::Error::other("dns requires local address")),
                     };
 
                     let mut server_builder = {
@@ -502,7 +497,7 @@ impl Server {
                 ProtocolType::FakeDns => {
                     let client_addr = match local_config.addr {
                         Some(a) => a,
-                        None => return Err(io::Error::new(ErrorKind::Other, "dns requires local address")),
+                        None => return Err(io::Error::other("dns requires local address")),
                     };
 
                     let mut builder = FakeDnsBuilder::new(client_addr);
