@@ -3,7 +3,6 @@ use std::{
     net::SocketAddr,
 };
 
-use async_trait::async_trait;
 use shadowsocks::net::AcceptOpts;
 use tokio::net::{TcpListener, TcpStream};
 
@@ -12,7 +11,6 @@ use crate::{
     local::redir::redir_ext::{TcpListenerRedirExt, TcpStreamRedirExt},
 };
 
-#[async_trait]
 impl TcpListenerRedirExt for TcpListener {
     async fn bind_redir(_ty: RedirType, _addr: SocketAddr, _accept_opts: AcceptOpts) -> io::Result<TcpListener> {
         let err = Error::new(
