@@ -71,8 +71,8 @@ impl UdpRedirSocket {
 
         socket.set_nonblocking(true)?;
         socket.set_reuse_address(true)?;
-        if reuse_port {
-            if let Err(err) = socket.set_reuse_port(true) {
+        if reuse_port
+            && let Err(err) = socket.set_reuse_port(true) {
                 if let Some(libc::ENOPROTOOPT) = err.raw_os_error() {
                     // SO_REUSEPORT is supported after 3.9
                     trace!("failed to set SO_REUSEPORT, error: {}", err);
@@ -81,7 +81,6 @@ impl UdpRedirSocket {
                     return Err(err);
                 }
             }
-        }
 
         let sock_addr = SockAddr::from(addr);
 
