@@ -189,11 +189,10 @@ impl UdpSocket {
     /// Wrapper of `UdpSocket::poll_send`
     pub fn poll_send(&self, cx: &mut TaskContext<'_>, buf: &[u8]) -> Poll<io::Result<usize>> {
         // Check MTU
-        if let Some(mtu) = self.mtu {
-            if buf.len() > mtu {
+        if let Some(mtu) = self.mtu
+            && buf.len() > mtu {
                 return Err(make_mtu_error(buf.len(), mtu)).into();
             }
-        }
 
         self.socket.poll_send(cx, buf)
     }
@@ -202,11 +201,10 @@ impl UdpSocket {
     #[inline]
     pub async fn send(&self, buf: &[u8]) -> io::Result<usize> {
         // Check MTU
-        if let Some(mtu) = self.mtu {
-            if buf.len() > mtu {
+        if let Some(mtu) = self.mtu
+            && buf.len() > mtu {
                 return Err(make_mtu_error(buf.len(), mtu));
             }
-        }
 
         self.socket.send(buf).await
     }
@@ -214,11 +212,10 @@ impl UdpSocket {
     /// Wrapper of `UdpSocket::poll_send_to`
     pub fn poll_send_to(&self, cx: &mut TaskContext<'_>, buf: &[u8], target: SocketAddr) -> Poll<io::Result<usize>> {
         // Check MTU
-        if let Some(mtu) = self.mtu {
-            if buf.len() > mtu {
+        if let Some(mtu) = self.mtu
+            && buf.len() > mtu {
                 return Err(make_mtu_error(buf.len(), mtu)).into();
             }
-        }
 
         self.socket.poll_send_to(cx, buf, target)
     }
@@ -227,11 +224,10 @@ impl UdpSocket {
     #[inline]
     pub async fn send_to<A: ToSocketAddrs>(&self, buf: &[u8], target: A) -> io::Result<usize> {
         // Check MTU
-        if let Some(mtu) = self.mtu {
-            if buf.len() > mtu {
+        if let Some(mtu) = self.mtu
+            && buf.len() > mtu {
                 return Err(make_mtu_error(buf.len(), mtu));
             }
-        }
 
         self.socket.send_to(buf, target).await
     }
@@ -241,11 +237,10 @@ impl UdpSocket {
     pub fn poll_recv(&self, cx: &mut TaskContext<'_>, buf: &mut ReadBuf<'_>) -> Poll<io::Result<()>> {
         ready!(self.socket.poll_recv(cx, buf))?;
 
-        if let Some(mtu) = self.mtu {
-            if buf.filled().len() > mtu {
+        if let Some(mtu) = self.mtu
+            && buf.filled().len() > mtu {
                 return Err(make_mtu_error(buf.filled().len(), mtu)).into();
             }
-        }
 
         Ok(()).into()
     }
@@ -255,11 +250,10 @@ impl UdpSocket {
     pub async fn recv(&self, buf: &mut [u8]) -> io::Result<usize> {
         let n = self.socket.recv(buf).await?;
 
-        if let Some(mtu) = self.mtu {
-            if n > mtu {
+        if let Some(mtu) = self.mtu
+            && n > mtu {
                 return Err(make_mtu_error(n, mtu));
             }
-        }
 
         Ok(n)
     }
@@ -269,11 +263,10 @@ impl UdpSocket {
     pub fn poll_recv_from(&self, cx: &mut TaskContext<'_>, buf: &mut ReadBuf<'_>) -> Poll<io::Result<SocketAddr>> {
         let addr = ready!(self.socket.poll_recv_from(cx, buf))?;
 
-        if let Some(mtu) = self.mtu {
-            if buf.filled().len() > mtu {
+        if let Some(mtu) = self.mtu
+            && buf.filled().len() > mtu {
                 return Err(make_mtu_error(buf.filled().len(), mtu)).into();
             }
-        }
 
         Ok(addr).into()
     }
@@ -283,11 +276,10 @@ impl UdpSocket {
     pub async fn recv_from(&self, buf: &mut [u8]) -> io::Result<(usize, SocketAddr)> {
         let (n, addr) = self.socket.recv_from(buf).await?;
 
-        if let Some(mtu) = self.mtu {
-            if n > mtu {
+        if let Some(mtu) = self.mtu
+            && n > mtu {
                 return Err(make_mtu_error(n, mtu));
             }
-        }
 
         Ok((n, addr))
     }
