@@ -159,11 +159,10 @@ where
 
         // Wakeup writer task because we have already received the salt
         #[cfg(feature = "aead-cipher-2022")]
-        if let ProxyServerStreamWriteState::PrepareHeader(waker) = this.writer_state {
-            if let Some(waker) = waker.take() {
+        if let ProxyServerStreamWriteState::PrepareHeader(waker) = this.writer_state
+            && let Some(waker) = waker.take() {
                 waker.wake();
             }
-        }
 
         Ok(()).into()
     }
@@ -190,11 +189,10 @@ where
                         *(this.writer_state) = ProxyServerStreamWriteState::Established;
                     } else {
                         // Reader didn't receive the salt from client yet.
-                        if let Some(waker) = waker.take() {
-                            if !waker.will_wake(cx.waker()) {
+                        if let Some(waker) = waker.take()
+                            && !waker.will_wake(cx.waker()) {
                                 waker.wake();
                             }
-                        }
                         *waker = Some(cx.waker().clone());
                         return Poll::Pending;
                     }
