@@ -255,8 +255,7 @@ where
                     Ok(..) => {
                         trace!(
                             "copy bidirection ends, a_to_b: {:?}, b_to_a: {:?}",
-                            self.a_to_b,
-                            self.b_to_a
+                            self.a_to_b, self.b_to_a
                         );
                     }
                     Err(ref err) => {
