@@ -3,10 +3,9 @@
 use std::process::ExitCode;
 
 use base64::Engine as _;
-use clap::{builder::PossibleValuesParser, Arg, ArgAction, ArgMatches, Command};
-use rand::RngCore;
+use clap::{Arg, ArgAction, ArgMatches, Command, builder::PossibleValuesParser};
 
-use shadowsocks_service::shadowsocks::crypto::{available_ciphers, CipherKind};
+use shadowsocks_service::shadowsocks::crypto::{CipherKind, available_ciphers};
 
 /// Defines command line options
 pub fn define_command_line_options(mut app: Command) -> Command {
@@ -34,8 +33,7 @@ pub fn main(matches: &ArgMatches) -> ExitCode {
     let key_len = method.key_len();
     if key_len > 0 {
         let mut key = vec![0u8; key_len];
-        let mut rng = rand::thread_rng();
-        rng.fill_bytes(&mut key);
+        rand::fill(key.as_mut_slice());
 
         let encoded_key = base64::engine::general_purpose::STANDARD.encode(&key);
         println!("{encoded_key}");
