@@ -148,6 +148,8 @@ pub fn define_command_line_options(mut app: Command) -> Command {
             .arg(
                 Arg::new("LOG_CONFIG")
                     .long("log-config")
+                    // deprecated for removal
+                    .hide(true)
                     .num_args(1)
                     .action(ArgAction::Set)
                     .value_parser(clap::value_parser!(PathBuf))
@@ -297,7 +299,7 @@ pub fn create(matches: &ArgMatches) -> ShadowsocksResult<(Runtime, impl Future<O
                 logging::init_with_file(path);
             }
             None => {
-                logging::init_with_config("sslocal", &service_config.log);
+                logging::init_with_config("ssmanager", &service_config.log);
             }
         }
 
@@ -402,17 +404,15 @@ pub fn create(matches: &ArgMatches) -> ShadowsocksResult<(Runtime, impl Future<O
         }
 
         // Overrides
-        if matches.get_flag("UDP_ONLY") {
-            if let Some(ref mut m) = config.manager {
+        if matches.get_flag("UDP_ONLY")
+            && let Some(ref mut m) = config.manager {
                 m.mode = Mode::UdpOnly;
             }
-        }
 
-        if matches.get_flag("TCP_AND_UDP") {
-            if let Some(ref mut m) = config.manager {
+        if matches.get_flag("TCP_AND_UDP")
+            && let Some(ref mut m) = config.manager {
                 m.mode = Mode::TcpAndUdp;
             }
-        }
 
         if let Some(acl_file) = matches.get_one::<String>("ACL") {
             let acl = AccessControl::load_from_file(acl_file)
