@@ -9,7 +9,7 @@ use shadowsocks_service::{
     config::{Config, ConfigType, LocalConfig, LocalInstanceConfig, ProtocolType, ServerInstanceConfig},
     local::socks::client::socks5::Socks5UdpClient,
     run_local, run_server,
-    shadowsocks::{config::Mode, crypto::CipherKind, relay::socks5::Address, ServerConfig},
+    shadowsocks::{ServerConfig, config::Mode, crypto::CipherKind, relay::socks5::Address},
 };
 
 const SERVER_ADDR: &str = "127.0.0.1:8093";
